@@ -46,10 +46,27 @@ use File::Spec;
 use File::Path qw'mkpath rmtree';
 sub init_vim_runtime {
     my $paths = [ ];
-    for my $subdir ( qw(plugin doc syntax colors after ftplugin indent autoload) ) {
-        push @$paths ,
-            File::Spec->join( runtime_path , $subdir );
-    }
+
+#   filetype.vim
+#   scripts.vim
+#   menu.vim
+    push @$paths , File::Spec->join( runtime_path , $_ )
+        for ( qw(
+                after
+                autoload
+                colors
+                compiler
+                doc
+                ftplugin
+                indent
+                keymap
+                lang
+                plugin
+                print
+                spell
+                syntax
+                tutor    ) );
+
     mkpath $paths;
 }
 
